@@ -141,18 +141,19 @@ Getopt_long::report (Errorcod c)
   switch (c)
     {
     case E_ARGEXPECT:
-      str += _f ("option `%s' requires an argument",
-                 found_option_->to_string ());
+      str
+        += _f ("option `%s' requires an argument", found_option_->to_string ());
       break;
     case E_NOARGEXPECT:
       str += _f ("option `%s' does not allow an argument",
                  found_option_->to_string ());
       break;
     case E_UNKNOWNOPTION:
-      str += _f ("unrecognized option: `%s'",
-                 argument_index_
-                 ? ("-" + string (1, arg_value_char_a_a_[array_index_][argument_index_]))
-                 : string (arg_value_char_a_a_[array_index_]));
+      str += _f (
+        "unrecognized option: `%s'",
+        argument_index_ ? (
+          "-" + string (1, arg_value_char_a_a_[array_index_][argument_index_]))
+                        : string (arg_value_char_a_a_[array_index_]));
       break;
     case E_ILLEGALARG:
       str += _f ("invalid argument `%s' to option `%s'",
@@ -208,7 +209,7 @@ Getopt_long::parseshort ()
 }
 
 const Long_option_init *
-Getopt_long::operator () ()
+Getopt_long::operator() ()
 {
   if (!ok ())
     return 0;
@@ -225,7 +226,7 @@ Getopt_long::operator () ()
   if (argument[0] != '-')
     return 0;
 
-  if (argument[1] == '-')  // what to do with "command  --  bla"
+  if (argument[1] == '-') // what to do with "command  --  bla"
     {
       if (argument[2])
         return parselong ();
@@ -234,7 +235,7 @@ Getopt_long::operator () ()
     }
   else
     {
-      if (argument[ 1 ])
+      if (argument[1])
         {
           argument_index_ = 1;
           return parseshort ();
@@ -254,7 +255,8 @@ Getopt_long::Getopt_long (int c, char **v, Long_option_init *lo)
 
   //    reached end of option table?
   table_len_ = 0;
-  for (int i = 0; option_a_[i].longname_str0_ || option_a_[i].shortname_char_; i++)
+  for (int i = 0; option_a_[i].longname_str0_ || option_a_[i].shortname_char_;
+       i++)
     table_len_++;
 }
 
@@ -324,7 +326,8 @@ Long_option_init::table_string (Long_option_init *l)
 int
 Long_option_init::compare (Long_option_init const &a, Long_option_init const &b)
 {
-  if (a.shortname_char_ && b.shortname_char_ && a.shortname_char_ - b.shortname_char_)
+  if (a.shortname_char_ && b.shortname_char_
+      && a.shortname_char_ - b.shortname_char_)
     return a.shortname_char_ - b.shortname_char_;
 
   if (b.shortname_char_ && a.longname_str0_)
