@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2021 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2022 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,20 +24,6 @@
 
 using std::vector;
 
-Audio_element_info::Audio_element_info (Audio_element *s, Stream_event *r)
-{
-  elem_ = s;
-  origin_trans_ = 0;
-  event_ = r;
-}
-
-Audio_element_info::Audio_element_info ()
-{
-  elem_ = 0;
-  event_ = 0;
-  origin_trans_ = 0;
-}
-
 vector<Context *>
 Audio_element_info::origin_contexts (Translator *end) const
 {
