@@ -120,8 +120,8 @@ Completion_rest_engraver::next_moment (Rational const &note_len)
 
   if (*mpos > *mlen)
     {
-      programming_error ("invalid measure position: "
-                         + to_string (*mpos) + " of " + to_string (*mlen));
+      programming_error ("invalid measure position: " + to_string (*mpos)
+                         + " of " + to_string (*mlen));
       return result;
     }
 
@@ -157,8 +157,7 @@ Completion_rest_engraver::next_moment (Rational const &note_len)
       Rational const step_unit = result / unit;
       if (step_unit.den () < step_unit.num ())
         {
-          int const log2
-            = intlog2 (int (step_unit.num () / step_unit.den ()));
+          int const log2 = intlog2 (int (step_unit.num () / step_unit.den ()));
           result = unit * Rational (1 << log2);
         }
     }
@@ -210,9 +209,8 @@ Completion_rest_engraver::process_music ()
       rest_dur = *orig;
       SCM factor = get_property (this, "completionFactor");
       if (ly_is_procedure (factor))
-        factor = ly_call (factor,
-                          context ()->self_scm (),
-                          rest_dur.smobbed_copy ());
+        factor
+          = ly_call (factor, context ()->self_scm (), rest_dur.smobbed_copy ());
       factor_ = from_scm<Rational> (factor, rest_dur.factor ());
       left_to_do_ = orig->get_length ();
     }
@@ -236,7 +234,8 @@ Completion_rest_engraver::process_music ()
       SCM pits = get_property (rest_events_[i], "pitch");
       set_property (event, "pitch", pits);
       set_property (event, "duration", rest_dur.smobbed_copy ());
-      set_property (event, "length", Moment (rest_dur.get_length ()).smobbed_copy ());
+      set_property (event, "length",
+                    Moment (rest_dur.get_length ()).smobbed_copy ());
       set_property (event, "duration-log", to_scm (rest_dur.duration_log ()));
 
       Item *rest = make_rest (event);
@@ -248,9 +247,8 @@ Completion_rest_engraver::process_music ()
   left_to_do_ -= rest_dur.get_length ();
   if (left_to_do_)
     {
-      find_global_context ()
-      ->add_moment_to_process (Moment (now.main_part_
-                                       + rest_dur.get_length ()));
+      find_global_context ()->add_moment_to_process (
+        Moment (now.main_part_ + rest_dur.get_length ()));
     }
   /*
     don't do complicated arithmetic with grace rests.
