@@ -23,8 +23,7 @@
 #include "stencil.hh"
 #include "modified-font-metric.hh"
 
-LY_DEFINE (ly_font_get_glyph, "ly:font-get-glyph",
-           2, 0, 0,
+LY_DEFINE (ly_font_get_glyph, "ly:font-get-glyph", 2, 0, 0,
            (SCM font, SCM name),
            R"(
 Return a stencil from @var{font} for the glyph named @var{name}.  If the glyph
@@ -45,8 +44,7 @@ and @code{fetaBraces}, respectively.
   return m.smobbed_copy ();
 }
 
-LY_DEFINE (ly_font_glyph_name_to_index, "ly:font-glyph-name-to-index",
-           2, 0, 0,
+LY_DEFINE (ly_font_glyph_name_to_index, "ly:font-glyph-name-to-index", 2, 0, 0,
            (SCM font, SCM name),
            R"(
 Return the index for @var{name} in @var{font}.
@@ -67,8 +65,7 @@ and @code{fetaBraces}, respectively.
     return to_scm (-1);
 }
 
-LY_DEFINE (ly_font_index_to_charcode, "ly:font-index-to-charcode",
-           2, 0, 0,
+LY_DEFINE (ly_font_index_to_charcode, "ly:font-index-to-charcode", 2, 0, 0,
            (SCM font, SCM index),
            R"(
 Return the character code for @var{index} in @var{font}.
@@ -88,9 +85,8 @@ and @code{fetaBraces}, respectively.
   return to_scm (charcode);
 }
 
-LY_DEFINE (ly_font_glyph_name_to_charcode, "ly:font-glyph-name-to-charcode",
-           2, 0, 0,
-           (SCM font, SCM name),
+LY_DEFINE (ly_font_glyph_name_to_charcode, "ly:font-glyph-name-to-charcode", 2,
+           0, 0, (SCM font, SCM name),
            R"(
 Return the character code for glyph @var{name} in @var{font}.
 
@@ -103,15 +99,14 @@ and @code{fetaBraces}, respectively.
   auto *const fm = LY_ASSERT_SMOB (Font_metric, font, 1);
   LY_ASSERT_TYPE (scm_is_string, name, 2);
 
-  return to_scm (fm->index_to_charcode (fm->name_to_index (ly_scm2string (name))));
+  return to_scm (
+    fm->index_to_charcode (fm->name_to_index (ly_scm2string (name))));
 }
 
 /*
   TODO: when are non string retvals allowed?
  */
-LY_DEFINE (ly_font_file_name, "ly:font-file-name",
-           1, 0, 0,
-           (SCM font),
+LY_DEFINE (ly_font_file_name, "ly:font-file-name", 1, 0, 0, (SCM font),
            R"(
 Given the font metric @var{font}, return the corresponding file name.
            )")
@@ -123,9 +118,7 @@ Given the font metric @var{font}, return the corresponding file name.
   return name;
 }
 
-LY_DEFINE (ly_font_name, "ly:font-name",
-           1, 0, 0,
-           (SCM font),
+LY_DEFINE (ly_font_name, "ly:font-name", 1, 0, 0, (SCM font),
            R"(
 Given the font metric @var{font}, return the corresponding name.
            )")
@@ -135,8 +128,7 @@ Given the font metric @var{font}, return the corresponding name.
   return ly_string2scm (fm->font_name ());
 }
 
-LY_DEFINE (ly_font_magnification, "ly:font-magnification", 1, 0, 0,
-           (SCM font),
+LY_DEFINE (ly_font_magnification, "ly:font-magnification", 1, 0, 0, (SCM font),
            R"(
 Given the font metric @var{font}, return the magnification, relative to the
 current @code{output-scale}.
@@ -147,8 +139,7 @@ current @code{output-scale}.
   return to_scm (fm->magnification ());
 }
 
-LY_DEFINE (ly_font_design_size, "ly:font-design-size", 1, 0, 0,
-           (SCM font),
+LY_DEFINE (ly_font_design_size, "ly:font-design-size", 1, 0, 0, (SCM font),
            R"(
 Given the font metric @var{font}, return the design size, relative to the
 current @code{output-scale}.
@@ -158,4 +149,3 @@ current @code{output-scale}.
 
   return to_scm (fm->design_size ());
 }
-
