@@ -47,8 +47,7 @@ Font_metric::find_by_name (string s) const
   SCM expr = SCM_EOL;
   if (idx != GLYPH_INDEX_INVALID)
     {
-      expr = ly_list (ly_symbol2scm ("named-glyph"),
-                      self_scm (),
+      expr = ly_list (ly_symbol2scm ("named-glyph"), self_scm (),
                       ly_string2scm (s));
       b = get_indexed_char_dimensions (idx);
     }
@@ -147,9 +146,7 @@ Font_metric::sub_fonts () const
 }
 
 Stencil
-Font_metric::text_stencil (Output_def *state,
-                           const string &,
-                           bool,
+Font_metric::text_stencil (Output_def *state, const string &, bool,
                            const string &) const
 {
   (void) state;
