@@ -30,7 +30,6 @@ class Grace_spacing_engraver : public Engraver
   TRANSLATOR_DECLARATIONS (Grace_spacing_engraver);
 
 protected:
-
   Moment last_moment_;
   Spanner *grace_spacing_;
 
@@ -57,8 +56,7 @@ Grace_spacing_engraver::process_music ()
     {
       Grob *column = unsmob<Grob> (get_property (this, "currentMusicalColumn"));
       Pointer_group_interface::add_grob (grace_spacing_,
-                                         ly_symbol2scm ("columns"),
-                                         column);
+                                         ly_symbol2scm ("columns"), column);
 
       set_object (column, "grace-spacing", grace_spacing_->self_scm ());
 
@@ -81,7 +79,6 @@ Grace_spacing_engraver::stop_translation_timestep ()
 void
 Grace_spacing_engraver::boot ()
 {
-
 }
 
 ADD_TRANSLATOR (Grace_spacing_engraver,
