@@ -56,9 +56,9 @@ Gregorian_ligature_engraver::listen_pes_or_flexa (Stream_event *ev)
   assign_event_once (pes_or_flexa_req_, ev);
 }
 
-void fix_prefix (char const *name, int mask,
-                 int *current_set, int min_set, int max_set,
-                 Grob *primitive)
+void
+fix_prefix (char const *name, int mask, int *current_set, int min_set,
+            int max_set, Grob *primitive)
 {
   bool current = *current_set & mask;
   bool min = min_set & mask;
@@ -80,13 +80,16 @@ void fix_prefix (char const *name, int mask,
     }
 }
 
-void fix_prefix_set (int *current_set, int min_set, int max_set, Grob *primitive)
+void
+fix_prefix_set (int *current_set, int min_set, int max_set, Grob *primitive)
 {
   fix_prefix ("virga", VIRGA, current_set, min_set, max_set, primitive);
   fix_prefix ("stropha", STROPHA, current_set, min_set, max_set, primitive);
-  fix_prefix ("inclinatum", INCLINATUM, current_set, min_set, max_set, primitive);
+  fix_prefix ("inclinatum", INCLINATUM, current_set, min_set, max_set,
+              primitive);
   fix_prefix ("auctum", AUCTUM, current_set, min_set, max_set, primitive);
-  fix_prefix ("descendens", DESCENDENS, current_set, min_set, max_set, primitive);
+  fix_prefix ("descendens", DESCENDENS, current_set, min_set, max_set,
+              primitive);
   fix_prefix ("ascendens", ASCENDENS, current_set, min_set, max_set, primitive);
   fix_prefix ("oriscus", ORISCUS, current_set, min_set, max_set, primitive);
   fix_prefix ("quilisma", QUILISMA, current_set, min_set, max_set, primitive);
@@ -96,7 +99,8 @@ void fix_prefix_set (int *current_set, int min_set, int max_set, Grob *primitive
   fix_prefix ("pes_or_flexa", LINEA, current_set, min_set, max_set, primitive);
 }
 
-void check_and_fix_all_prefixes (vector<Item *> const &primitives)
+void
+check_and_fix_all_prefixes (vector<Item *> const &primitives)
 {
   /* Check for invalid head modifier combinations */
   for (const auto &primitive : primitives)
@@ -105,93 +109,75 @@ void check_and_fix_all_prefixes (vector<Item *> const &primitives)
       int prefix_set
         = (VIRGA * from_scm<bool> (get_property (primitive, "virga")))
           | (STROPHA * from_scm<bool> (get_property (primitive, "stropha")))
-          | (INCLINATUM * from_scm<bool> (get_property (primitive, "inclinatum")))
+          | (INCLINATUM
+             * from_scm<bool> (get_property (primitive, "inclinatum")))
           | (AUCTUM * from_scm<bool> (get_property (primitive, "auctum")))
-          | (DESCENDENS * from_scm<bool> (get_property (primitive, "descendens")))
+          | (DESCENDENS
+             * from_scm<bool> (get_property (primitive, "descendens")))
           | (ASCENDENS * from_scm<bool> (get_property (primitive, "ascendens")))
           | (ORISCUS * from_scm<bool> (get_property (primitive, "oriscus")))
           | (QUILISMA * from_scm<bool> (get_property (primitive, "quilisma")))
           | (DEMINUTUM * from_scm<bool> (get_property (primitive, "deminutum")))
           | (CAVUM * from_scm<bool> (get_property (primitive, "cavum")))
           | (LINEA * from_scm<bool> (get_property (primitive, "linea")))
-          | (PES_OR_FLEXA * from_scm<bool> (get_property (primitive, "pes-or-flexa")));
+          | (PES_OR_FLEXA
+             * from_scm<bool> (get_property (primitive, "pes-or-flexa")));
 
       /* check: ascendens and descendens exclude each other; same with
          auctum and deminutum */
       if (prefix_set & DESCENDENS)
         {
-          fix_prefix_set (&prefix_set,
-                          prefix_set & ~ASCENDENS,
-                          prefix_set & ~ASCENDENS,
-                          primitive);
+          fix_prefix_set (&prefix_set, prefix_set & ~ASCENDENS,
+                          prefix_set & ~ASCENDENS, primitive);
         }
       if (prefix_set & AUCTUM)
         {
-          fix_prefix_set (&prefix_set,
-                          prefix_set & ~DEMINUTUM,
-                          prefix_set & ~DEMINUTUM,
-                          primitive);
+          fix_prefix_set (&prefix_set, prefix_set & ~DEMINUTUM,
+                          prefix_set & ~DEMINUTUM, primitive);
         }
 
       /* check: virga, quilisma and oriscus cannot be combined with any
          other prefix, but may be part of a pes or flexa */
       if (prefix_set & VIRGA)
         {
-          fix_prefix_set (&prefix_set,
-                          VIRGA,
-                          VIRGA | PES_OR_FLEXA,
-                          primitive);
+          fix_prefix_set (&prefix_set, VIRGA, VIRGA | PES_OR_FLEXA, primitive);
         }
       if (prefix_set & QUILISMA)
         {
-          fix_prefix_set (&prefix_set,
-                          QUILISMA,
-                          QUILISMA | PES_OR_FLEXA,
+          fix_prefix_set (&prefix_set, QUILISMA, QUILISMA | PES_OR_FLEXA,
                           primitive);
         }
       if (prefix_set & ORISCUS)
         {
-          fix_prefix_set (&prefix_set,
-                          ORISCUS,
-                          ORISCUS | PES_OR_FLEXA,
+          fix_prefix_set (&prefix_set, ORISCUS, ORISCUS | PES_OR_FLEXA,
                           primitive);
         }
 
       /* check: auctum is the only valid optional prefix for stropha */
       if (prefix_set & STROPHA)
         {
-          fix_prefix_set (&prefix_set,
-                          STROPHA,
-                          STROPHA | AUCTUM,
-                          primitive);
+          fix_prefix_set (&prefix_set, STROPHA, STROPHA | AUCTUM, primitive);
         }
 
       /* check: inclinatum may be prefixed with auctum or deminutum only */
       if (prefix_set & INCLINATUM)
         {
-          fix_prefix_set (&prefix_set,
-                          INCLINATUM,
-                          INCLINATUM | AUCTUM | DEMINUTUM,
-                          primitive);
+          fix_prefix_set (&prefix_set, INCLINATUM,
+                          INCLINATUM | AUCTUM | DEMINUTUM, primitive);
         }
       /* check: semivocalis (deminutum but not inclinatum) must occur in
          combination with and only with pes or flexa */
       else if (prefix_set & DEMINUTUM)
         {
-          fix_prefix_set (&prefix_set,
-                          DEMINUTUM | PES_OR_FLEXA,
-                          DEMINUTUM | PES_OR_FLEXA,
-                          primitive);
+          fix_prefix_set (&prefix_set, DEMINUTUM | PES_OR_FLEXA,
+                          DEMINUTUM | PES_OR_FLEXA, primitive);
         }
 
       /* check: cavum and linea (either or both) may be applied only
          upon core punctum */
       if (prefix_set & (CAVUM | LINEA))
         {
-          fix_prefix_set (&prefix_set,
-                          0,
-                          CAVUM | LINEA,
-                          primitive);
+          fix_prefix_set (&prefix_set, 0, CAVUM | LINEA, primitive);
         }
 
       /* all other combinations should be valid (unless I made a
@@ -222,7 +208,8 @@ provide_context_info (vector<Item *> const &primitives)
       if (prefix_set & PES_OR_FLEXA)
         {
           if (!i) // ligature may not start with 2nd head of pes or flexa
-            primitive->warning (_ ("cannot apply `\\~' on first head of ligature"));
+            primitive->warning (
+              _ ("cannot apply `\\~' on first head of ligature"));
           else if (pitch > prev_pitch) // pes
             {
               prev_context_info |= PES_LOWER;
@@ -234,7 +221,8 @@ provide_context_info (vector<Item *> const &primitives)
               context_info |= FLEXA_RIGHT;
             }
           else // (pitch == prev_pitch)
-            primitive->warning (_ ("cannot apply `\\~' on heads with identical pitch"));
+            primitive->warning (
+              _ ("cannot apply `\\~' on heads with identical pitch"));
         }
       if (prev_prefix_set & DEMINUTUM)
         context_info |= AFTER_DEMINUTUM;
@@ -248,8 +236,7 @@ provide_context_info (vector<Item *> const &primitives)
       prev_pitch = pitch;
     }
   if (prev_primitive)
-    set_property (prev_primitive, "context-info",
-                  to_scm (prev_context_info));
+    set_property (prev_primitive, "context-info", to_scm (prev_context_info));
 }
 
 void
