@@ -53,8 +53,8 @@ Key_signature_interface::print (SCM smob)
 
   SCM c0s = get_property (me, "c0-position");
 
-  bool is_cancellation = me->internal_has_interface
-                         (ly_symbol2scm ("key-cancellation-interface"));
+  bool is_cancellation
+    = me->internal_has_interface (ly_symbol2scm ("key-cancellation-interface"));
 
   /*
     SCM lists are stacks, so we work from right to left, ending with
@@ -68,14 +68,12 @@ Key_signature_interface::print (SCM smob)
   Font_metric *fm = Font_interface::get_default_font (me);
   SCM props = Font_interface::music_font_alist_chain (me);
   SCM alist = ly_chain_assoc_get (ly_symbol2scm ("alteration-glyph-name-alist"),
-                                  props,
-                                  SCM_EOL);
+                                  props, SCM_EOL);
 
-  for (SCM s = get_property (me, "alteration-alist"); scm_is_pair (s); s = scm_cdr (s))
+  for (SCM s = get_property (me, "alteration-alist"); scm_is_pair (s);
+       s = scm_cdr (s))
     {
-      SCM alt = is_cancellation
-                ? to_scm (0)
-                : scm_cdar (s);
+      SCM alt = is_cancellation ? to_scm (0) : scm_cdar (s);
 
       SCM glyph_name_scm = ly_assoc_get (alt, alist, SCM_BOOL_F);
       if (!scm_is_string (glyph_name_scm))
@@ -95,8 +93,9 @@ Key_signature_interface::print (SCM smob)
         {
           ht_right.set_empty ();
           Stencil column;
-          for (SCM pos_list = Lily::key_signature_interface_alteration_positions
-                              (scm_car (s), c0s, smob);
+          for (SCM pos_list
+               = Lily::key_signature_interface_alteration_positions (
+                 scm_car (s), c0s, smob);
                scm_is_pair (pos_list); pos_list = scm_cdr (pos_list))
             {
               int p = from_scm<int> (scm_car (pos_list));
@@ -109,8 +108,7 @@ Key_signature_interface::print (SCM smob)
             has vertical edges on both sides. A little padding is
             needed to prevent collisions.
           */
-          Real padding = from_scm<double> (get_property (me, "padding"),
-                                           0.0);
+          Real padding = from_scm<double> (get_property (me, "padding"), 0.0);
           SCM handle = ly_assoc (scm_cons (glyph_name_scm, last_glyph_name),
                                  padding_pairs);
           if (scm_is_pair (handle))
@@ -118,12 +116,12 @@ Key_signature_interface::print (SCM smob)
           else if (glyph_name == "accidentals.natural")
             if (!intersection (ht_right, last_ht_left).is_empty ())
               padding += (intersection (ht_right, last_ht_left).length ()
-                          ? 0.3     /* edges overlap */
-                          : 0.15);  /* just touching at the corners */
+                            ? 0.3    /* edges overlap */
+                            : 0.15); /* just touching at the corners */
 
           mol.add_at_edge (X_AXIS, LEFT, column, padding);
 
-          last_ht_left = ht_right + 3;  /* shift up (change to left side) */
+          last_ht_left = ht_right + 3; /* shift up (change to left side) */
           last_glyph_name = glyph_name_scm;
         }
     }
