@@ -39,15 +39,12 @@ struct Ledger_line_spanner
 
 static void
 set_rods (Drul_array<Interval> const &current_extents,
-          Drul_array<Interval> const &previous_extents,
-          Item *current_column,
-          Item *previous_column,
-          Real min_length)
+          Drul_array<Interval> const &previous_extents, Item *current_column,
+          Item *previous_column, Real min_length)
 {
   for (const auto d : {UP, DOWN})
     {
-      if (!current_extents[d].is_empty ()
-          && !previous_extents[d].is_empty ())
+      if (!current_extents[d].is_empty () && !previous_extents[d].is_empty ())
         {
           Rod rod;
           rod.distance_ = 2 * min_length
@@ -114,9 +111,8 @@ Ledger_line_spanner::set_spacing_rods (SCM smob)
       Item *column = h->get_column ();
       if (current_column != column)
         {
-          set_rods (current_extents, previous_extents,
-                    current_column, previous_column,
-                    current_head_width * min_length_fraction);
+          set_rods (current_extents, previous_extents, current_column,
+                    previous_column, current_head_width * min_length_fraction);
 
           previous_column = current_column;
           current_column = column;
@@ -137,9 +133,8 @@ Ledger_line_spanner::set_spacing_rods (SCM smob)
     }
 
   if (previous_column && current_column)
-    set_rods (current_extents, previous_extents,
-              current_column, previous_column,
-              current_head_width * min_length_fraction);
+    set_rods (current_extents, previous_extents, current_column,
+              previous_column, current_head_width * min_length_fraction);
 
   return SCM_UNSPECIFIED;
 }
@@ -165,10 +160,10 @@ struct Ledger_request
   Interval max_ledger_extent_;
   Interval max_head_extent_;
   int max_position_;
-  vector <Head_data> heads_;
+  vector<Head_data> heads_;
   // The map's keys are vertical ledger line positions. The values are
   // vectors of the x-extents of ledger lines.
-  std::map <Real, vector <Interval> > ledger_extents_;
+  std::map<Real, vector<Interval>> ledger_extents_;
   Ledger_request ()
   {
     max_ledger_extent_.set_empty ();
@@ -177,14 +172,14 @@ struct Ledger_request
   }
 };
 
-typedef std::map < int, Drul_array<Ledger_request> > Ledger_requests;
+typedef std::map<int, Drul_array<Ledger_request>> Ledger_requests;
 
 /*
   TODO: ledger share a lot of info. Lots of room to optimize away
   common use of objects/variables.
 */
-MAKE_SCHEME_CALLBACK (Ledger_line_spanner, print, "ly:ledger-line-spanner::print",
-                      1);
+MAKE_SCHEME_CALLBACK (Ledger_line_spanner, print,
+                      "ly:ledger-line-spanner::print", 1);
 SCM
 Ledger_line_spanner::print (SCM smob)
 {
@@ -238,8 +233,8 @@ Ledger_line_spanner::print (SCM smob)
           reqs[rank][vdir].max_ledger_extent_.unite (ledger_extent);
           reqs[rank][vdir].max_head_extent_.unite (head_extent);
           reqs[rank][vdir].max_position_
-            = vdir * std::max (vdir * reqs[rank][vdir].max_position_,
-                               vdir * pos);
+            = vdir
+              * std::max (vdir * reqs[rank][vdir].max_position_, vdir * pos);
           Head_data hd;
           hd.position_ = pos;
           hd.ledger_positions_ = ledger_positions;
@@ -259,8 +254,8 @@ Ledger_line_spanner::print (SCM smob)
   // produce more space between them.
   Real gap = from_scm<double> (get_property (me, "gap"), 0.1);
   Ledger_requests::iterator last (reqs.end ());
-  for (Ledger_requests::iterator i (reqs.begin ());
-       i != reqs.end (); last = i++)
+  for (Ledger_requests::iterator i (reqs.begin ()); i != reqs.end ();
+       last = i++)
     {
       if (last == reqs.end ())
         continue;
@@ -273,28 +268,30 @@ Ledger_line_spanner::print (SCM smob)
               && !staff_extent.contains (i->second[d].max_position_))
             {
               // Midpoint between the furthest bounds of the two heads.
-              Real center
-                = (last->second[d].max_head_extent_[RIGHT]
-                   + i->second[d].max_head_extent_[LEFT]) / 2;
+              Real center = (last->second[d].max_head_extent_[RIGHT]
+                             + i->second[d].max_head_extent_[LEFT])
+                            / 2;
 
               // Do both reqs have notes further than the first space
               // beyond the staff?
               // (due tilt of quarter note-heads)
               /* FIXME */
-              bool both
-                = (!staff_extent.contains (last->second[d].max_position_
-                                           - sign (last->second[d].max_position_))
-                   && !staff_extent.contains (i->second[d].max_position_
-                                              - sign (i->second[d].max_position_)));
+              bool both = (!staff_extent.contains (
+                             last->second[d].max_position_
+                             - sign (last->second[d].max_position_))
+                           && !staff_extent.contains (
+                             i->second[d].max_position_
+                             - sign (i->second[d].max_position_)));
 
               for (const auto which : {LEFT, RIGHT})
                 {
-                  Ledger_request &lr = ((which == LEFT) ? * last : *i).second[d];
+                  Ledger_request &lr = ((which == LEFT) ? *last : *i).second[d];
 
                   Real limit = (center + (both ? which * gap / 2 : 0));
                   lr.max_ledger_extent_.at (-which)
-                    = which * std::max (which * lr.max_ledger_extent_[-which],
-                                        which * limit);
+                    = which
+                      * std::max (which * lr.max_ledger_extent_[-which],
+                                  which * limit);
                 }
             }
         }
@@ -303,8 +300,7 @@ Ledger_line_spanner::print (SCM smob)
   // Iterate through ledger requests and the data they have about each
   // note head to generate the final extents for all ledger lines.
   // Note heads of different widths produce different ledger extents.
-  for (Ledger_requests::iterator i (reqs.begin ());
-       i != reqs.end (); i++)
+  for (Ledger_requests::iterator i (reqs.begin ()); i != reqs.end (); i++)
     {
       for (const auto d : {DOWN, UP})
         {
@@ -334,7 +330,8 @@ Ledger_line_spanner::print (SCM smob)
                       const auto dist
                         = (acc_extent.right () + head_size.left ()) / 2;
 
-                      Real left_shorten = std::max (-ledger_size[LEFT] + dist, 0.0);
+                      Real left_shorten
+                        = std::max (-ledger_size[LEFT] + dist, 0.0);
                       x_extent[LEFT] += left_shorten;
                       /*
                         TODO: shorten 2 ledger lines for the case
@@ -361,8 +358,8 @@ Ledger_line_spanner::print (SCM smob)
     {
       for (const auto d : {DOWN, UP})
         {
-          std::map<Real, vector<Interval> > &lex = i->second[d].ledger_extents_;
-          for (std::map<Real, vector<Interval> >::iterator k = lex.begin ();
+          std::map<Real, vector<Interval>> &lex = i->second[d].ledger_extents_;
+          for (std::map<Real, vector<Interval>>::iterator k = lex.begin ();
                k != lex.end (); k++)
             {
               Real lpos = k->first;
@@ -376,8 +373,8 @@ Ledger_line_spanner::print (SCM smob)
               for (vsize n = 0; n < x_extents.size (); n++)
                 {
                   // thickness (ledger line thickness) is the blot diameter
-                  Stencil line = Lookup::round_filled_box (Box (x_extents[n], y_extent),
-                                                           thickness);
+                  Stencil line = Lookup::round_filled_box (
+                    Box (x_extents[n], y_extent), thickness);
 
                   line.translate_axis (lpos * halfspace, Y_AXIS);
                   ledgers.add_stencil (line);
