@@ -33,8 +33,7 @@
 
 using std::string;
 
-LY_DEFINE (ly_parse_file, "ly:parse-file",
-           1, 0, 0, (SCM name),
+LY_DEFINE (ly_parse_file, "ly:parse-file", 1, 0, 0, (SCM name),
            R"(
 Parse a single @code{.ly} file.  Upon failure, throw @code{ly-file-failed} key.
            )")
@@ -98,8 +97,7 @@ Parse a single @code{.ly} file.  Upon failure, throw @code{ly-file-failed} key.
   if (init.length () && global_path.find (init).empty ())
     {
       warning (_f ("cannot find init file: `%s'", init));
-      warning (_f ("(search path: `%s')",
-                   global_path.to_string ().c_str ()));
+      warning (_f ("(search path: `%s')", global_path.to_string ().c_str ()));
       exit (2);
     }
 
@@ -169,8 +167,8 @@ Parse the init file @var{name}.
   return SCM_UNSPECIFIED;
 }
 
-LY_DEFINE (ly_parser_clone, "ly:parser-clone",
-           0, 2, 0, (SCM closures, SCM location),
+LY_DEFINE (ly_parser_clone, "ly:parser-clone", 0, 2, 0,
+           (SCM closures, SCM location),
            R"(
 Return a clone of current parser.  An association list of port positions to
 closures can be specified in @var{closures} in order to have @code{$} and
@@ -190,8 +188,8 @@ is a valid location, it becomes the source of all music expressions inside.
   return clone->unprotect ();
 }
 
-LY_DEFINE (ly_parser_define_x, "ly:parser-define!",
-           2, 0, 0, (SCM symbol, SCM val),
+LY_DEFINE (ly_parser_define_x, "ly:parser-define!", 2, 0, 0,
+           (SCM symbol, SCM val),
            R"(
 Bind @var{symbol} to @var{val} in current parser's module.
            )")
@@ -205,8 +203,7 @@ Bind @var{symbol} to @var{val} in current parser's module.
   return SCM_UNSPECIFIED;
 }
 
-LY_DEFINE (ly_parser_lookup, "ly:parser-lookup",
-           1, 0, 0, (SCM symbol),
+LY_DEFINE (ly_parser_lookup, "ly:parser-lookup", 1, 0, 0, (SCM symbol),
            R"(
 Look up @var{symbol} in current parser's module.  Return @code{'()} if not
 defined.
@@ -224,8 +221,8 @@ defined.
     return SCM_EOL;
 }
 
-LY_DEFINE (ly_parser_parse_string, "ly:parser-parse-string",
-           2, 0, 0, (SCM parser_smob, SCM ly_code),
+LY_DEFINE (ly_parser_parse_string, "ly:parser-parse-string", 2, 0, 0,
+           (SCM parser_smob, SCM ly_code),
            R"(
 Parse the string @var{ly-code} with @var{parser-smob}.  Upon failure, throw
 @code{ly-file-failed} key.
@@ -235,17 +232,17 @@ Parse the string @var{ly-code} with @var{parser-smob}.  Upon failure, throw
   LY_ASSERT_TYPE (scm_is_string, ly_code, 2);
 
   if (!parser->lexer_->is_clean ())
-    parser->parser_error (_ ("ly:parser-parse-string is only valid with a new parser."
-                             "  Use ly:parser-include-string instead."));
+    parser->parser_error (
+      _ ("ly:parser-parse-string is only valid with a new parser."
+         "  Use ly:parser-include-string instead."));
   else
     parser->parse_string (ly_scm2string (ly_code));
 
   return SCM_UNSPECIFIED;
 }
 
-LY_DEFINE (ly_parse_string_expression, "ly:parse-string-expression",
-           2, 2, 0, (SCM parser_smob, SCM ly_code, SCM filename,
-                     SCM line),
+LY_DEFINE (ly_parse_string_expression, "ly:parse-string-expression", 2, 2, 0,
+           (SCM parser_smob, SCM ly_code, SCM filename, SCM line),
            R"(
 Parse the string @var{ly-code} with @var{parser-smob}. Return the contained
 music expression.  @var{filename} and @var{line} are optional source
@@ -267,17 +264,17 @@ indicators.
 
   if (!parser->lexer_->is_clean ())
     {
-      parser->parser_error (_ ("ly:parse-string-expression is only valid with a new parser."
-                               "  Use ly:parser-include-string instead."));
+      parser->parser_error (
+        _ ("ly:parse-string-expression is only valid with a new parser."
+           "  Use ly:parser-include-string instead."));
       return SCM_UNSPECIFIED;
     }
 
-  return parser->parse_string_expression (ly_scm2string (ly_code),
-                                          fn, ln);
+  return parser->parse_string_expression (ly_scm2string (ly_code), fn, ln);
 }
 
-LY_DEFINE (ly_parser_include_string, "ly:parser-include-string",
-           1, 0, 0, (SCM ly_code),
+LY_DEFINE (ly_parser_include_string, "ly:parser-include-string", 1, 0, 0,
+           (SCM ly_code),
            R"(
 Include the string @var{ly-code} into the input stream for current parser.  Can
 only be used in immediate Scheme expressions (@code{$} instead of @code{#}).
@@ -293,8 +290,8 @@ only be used in immediate Scheme expressions (@code{$} instead of @code{#}).
   return SCM_UNSPECIFIED;
 }
 
-LY_DEFINE (ly_parser_set_note_names, "ly:parser-set-note-names",
-           1, 0, 0, (SCM names),
+LY_DEFINE (ly_parser_set_note_names, "ly:parser-set-note-names", 1, 0, 0,
+           (SCM names),
            R"(
 Replace current note names in parser.  @var{names} is an alist of symbols.
 This only has effect if the current mode is notes.
@@ -313,8 +310,8 @@ This only has effect if the current mode is notes.
   return SCM_UNSPECIFIED;
 }
 
-LY_DEFINE (ly_parser_output_name, "ly:parser-output-name",
-           0, 1, 0, (SCM parser),
+LY_DEFINE (ly_parser_output_name, "ly:parser-output-name", 0, 1, 0,
+           (SCM parser),
            R"(
 Return the base name of the output file.  If @var{parser} is left off, use
 currently active parser.
@@ -328,8 +325,7 @@ currently active parser.
   return ly_string2scm (p->output_basename_);
 }
 
-LY_DEFINE (ly_parser_error, "ly:parser-error",
-           1, 1, 0, (SCM msg, SCM input),
+LY_DEFINE (ly_parser_error, "ly:parser-error", 1, 1, 0, (SCM msg, SCM input),
            R"(
 Display an error message and make current parser fail.  Without a current
 parser, trigger an ordinary error.
@@ -360,8 +356,8 @@ parser, trigger an ordinary error.
   return SCM_UNSPECIFIED;
 }
 
-LY_DEFINE (ly_parser_clear_error, "ly:parser-clear-error",
-           0, 1, 0, (SCM parser),
+LY_DEFINE (ly_parser_clear_error, "ly:parser-clear-error", 0, 1, 0,
+           (SCM parser),
            R"(
 Clear error flag for @var{parser}, defaulting to current parser.
            )")
@@ -377,8 +373,7 @@ Clear error flag for @var{parser}, defaulting to current parser.
   return SCM_UNSPECIFIED;
 }
 
-LY_DEFINE (ly_parser_has_error_p, "ly:parser-has-error?",
-           0, 1, 0, (SCM parser),
+LY_DEFINE (ly_parser_has_error_p, "ly:parser-has-error?", 0, 1, 0, (SCM parser),
            R"(
 Does @var{parser} (defaulting to current parser) have an error flag?
            )")
