@@ -25,7 +25,8 @@ public:
   DECLARE_SCHEME_CALLBACK (length_callback, (SCM));
 };
 
-MAKE_SCHEME_CALLBACK (Lyric_combine_music, length_callback, 1);
+MAKE_SCHEME_CALLBACK (Lyric_combine_music, length_callback,
+                      "ly:lyric-combine-music::length-callback", 1);
 SCM
 Lyric_combine_music::length_callback (SCM m)
 {
