@@ -19,9 +19,8 @@
 
 #include "paper-score.hh"
 
-LY_DEFINE (ly_paper_score_paper_systems, "ly:paper-score-paper-systems",
-           1, 0, 0,
-           (SCM paper_score),
+LY_DEFINE (ly_paper_score_paper_systems, "ly:paper-score-paper-systems", 1, 0,
+           0, (SCM paper_score),
            R"(
 Return vector of @code{paper_system} objects from @var{paper-score}.
            )")
