@@ -26,8 +26,7 @@
 using std::string;
 using std::vector;
 
-LY_DEFINE (ly_type1_2_pfa, "ly:type1->pfa",
-           1, 0, 0, (SCM type1_file_name),
+LY_DEFINE (ly_type1_2_pfa, "ly:type1->pfa", 1, 0, 0, (SCM type1_file_name),
            R"(
 Convert the contents of a Type@tie{}1 font in PFB format to PFA format.  If the
 file is already in PFA format, pass it through.
@@ -51,8 +50,8 @@ file is already in PFA format, pass it through.
   else
     {
       /* The file is in PFA format. Pass it through. */
-      pfa_scm = scm_from_latin1_stringn (&type1_string[0],
-                                         type1_string.size ());
+      pfa_scm
+        = scm_from_latin1_stringn (&type1_string[0], type1_string.size ());
     }
 
   debug_output ("]", false);
@@ -60,8 +59,7 @@ file is already in PFA format, pass it through.
   return pfa_scm;
 }
 
-LY_DEFINE (ly_otf_2_cff, "ly:otf->cff",
-           1, 1, 0, (SCM otf_file_name, SCM idx),
+LY_DEFINE (ly_otf_2_cff, "ly:otf->cff", 1, 1, 0, (SCM otf_file_name, SCM idx),
            R"(
 Convert the contents of an OTF file to a CFF file, returning it as a string.
 The optional @var{idx} argument is useful for OpenType/CFF collections (OTC)
