@@ -20,8 +20,9 @@
 #include "pointer-group-interface.hh"
 #include "grob.hh"
 
-LY_DEFINE (ly_pointer_group_interface__add_grob, "ly:pointer-group-interface::add-grob",
-           3, 0, 0, (SCM grob, SCM sym, SCM grob_element),
+LY_DEFINE (ly_pointer_group_interface__add_grob,
+           "ly:pointer-group-interface::add-grob", 3, 0, 0,
+           (SCM grob, SCM sym, SCM grob_element),
            R"(
 Add @var{grob-element} to @var{grob}'s @var{sym} grob array.
            )")
@@ -33,4 +34,3 @@ Add @var{grob-element} to @var{grob}'s @var{sym} grob array.
   Pointer_group_interface::add_grob (g, sym, elem);
   return SCM_UNSPECIFIED;
 }
-
