@@ -60,7 +60,8 @@ Pointer_group_interface::get_grob_array (Grob *me, SCM sym)
 }
 
 Grob *
-Pointer_group_interface::find_grob (Grob *me, SCM sym, bool (*pred) (Grob const *))
+Pointer_group_interface::find_grob (Grob *me, SCM sym,
+                                    bool (*pred) (Grob const *))
 {
   Grob_array *arr = get_grob_array (me, sym);
 
@@ -98,9 +99,8 @@ ly_scm2link_array (SCM x)
 vector<Grob *> const &
 internal_extract_grob_array (Grob const *elt, SCM symbol)
 {
-  return elt
-         ? ly_scm2link_array (elt->internal_get_object (symbol))
-         : empty_array;
+  return elt ? ly_scm2link_array (elt->internal_get_object (symbol))
+             : empty_array;
 }
 
 vector<Item *>
