@@ -24,8 +24,8 @@ Protected_scm context_property_lookup_table;
 Protected_scm grob_property_lookup_table;
 Protected_scm prob_property_lookup_table;
 
-LY_DEFINE (ly_property_lookup_stats, "ly:property-lookup-stats",
-           1, 0, 0, (SCM sym),
+LY_DEFINE (ly_property_lookup_stats, "ly:property-lookup-stats", 1, 0, 0,
+           (SCM sym),
            R"(
 Return hash table with a property access corresponding to @var{sym}.  Choices
 are @code{prob}, @code{grob}, and @code{context}.
