@@ -174,7 +174,7 @@ Text_interface::interpret_string (SCM layout_smob, SCM props, SCM markup)
      contains newlines.  We do it on every recursive call, so the result
      of a string transformer is also modified this way. */
   for (auto &ch : str)
-    if (isspace (ch))
+    if (!(ch & 0x80) && isspace (ch)) // don't mess up multibyte chars
       ch = ' ';
 
   Font_metric *fm = select_encoded_font (layout, props);
