@@ -48,7 +48,7 @@
 ;; (define *base-octave-shift* -2)
 (define *base-octave-shift* (make-parameter 0))
 
-;; The coeficient by which the notes just before \breath are shortened.
+;; The coefficient by which the notes just before \breathe are shortened.
 (define-public *breathe-shortage* (make-parameter 0.8))
 
 
@@ -60,9 +60,7 @@
       (debug-enable 'backtrace))
   (ly:message "Writing Festival XML file ~a..." filename)
   (let ((port (open-output-file filename)))
-    (cond-expand
-     (guile-2 (set-port-encoding! port "UTF-8"))
-     (else))
+    (set-port-encoding! port "UTF-8")
     (write-header port tempo)
     (write-lyrics port music)
     (write-footer port)
