@@ -6,7 +6,7 @@ GITLAB_API="https://gitlab.com/api/v4"
 GITLAB_API_PROJECT="$GITLAB_API/projects/lilypond%2Flilypond"
 
 REF_NAME="master"
-JOB_NAME="test-baseline:ubuntu-16.04"
+JOB_NAME="test-baseline"
 
 # FIXME: Always downloads the latest test-baseline; likely want the one for the
 # base commit of the current merge request.
@@ -23,7 +23,7 @@ if [ -z "${GITLAB_CI-}" ]; then
   echo "locally, you need to adapt the stored paths to match your setup:" >&2
   echo " - The source directory was \`/builds/lilypond/lilypond/'." >&2
   echo " - The build directory was \`/builds/lilypond/lilypond/build/'." >&2
-  echo " - Fonts were installed as packaged by Ubuntu 16.04, for example" >&2
+  echo " - Fonts were installed as packaged by Ubuntu 18.04, for example" >&2
   echo "   DejaVu Sans in \`/usr/share/fonts/truetype/dejavu/DejaVuSans.ttf'." >&2
   exit 1
 fi
