@@ -91,6 +91,9 @@ Use the LSR database to regenerate LilyPond's 'snippets' directory.
   -t, --textdump=FILE    create a plain text dump file of all snippets
                            (omitting binary fields) in the LSR
                            database dump; ignored if '--dump=no'
+  -T, --textdump-only=FILE
+                         shorthand for '--no-convert --no-lsr
+                         --no-new --no-snippet-list --textdump=FILE'
   -V, --verbose          be verbose
 
 Environment variables:
@@ -151,6 +154,7 @@ my $no_new = 0;
 my $no_snippet_list = 0;
 my $path = "";
 my $textdump = "";
+my $textdump_only = "";
 my $top_source = ".";
 my $verbose = 0;
 
@@ -165,6 +169,7 @@ GetOptions(
   "no-snippet-list|f" => \$no_snippet_list,
   "path|p=s" => \$path,
   "textdump|t=s" => \$textdump,
+  "textdump-only|T=s" => \$textdump_only,
   "top-source|s=s" => \$top_source,
   "verbose|V" => \$verbose,
   ) || show_help(2);
@@ -175,13 +180,21 @@ if ($new) {
   $no_lsr = 1;
 }
 
+if ($textdump_only) {
+  $no_convert = 1;
+  $no_lsr = 1;
+  $no_new = 1;
+  $no_snippet_list = 1;
+  $textdump = $textdump_only;
+}
+
 # Check availability of external programs.
-if (!$no_lsr) {
+unless ($no_lsr) {
   pandoc or die "error: 'pandoc' executable not found\n";
 }
 
 my $CONVERT_LY = "";
-if (!$no_convert) {
+unless ($no_convert) {
   if ($path) {
     $CONVERT_LY = catfile($path, "convert-ly");
     if (!-x $CONVERT_LY) {
@@ -226,34 +239,38 @@ if (!$no_convert) {
 
 
 # Check the actual snippet directories.
-my @dirs;
 my $snippet_dir = catdir("Documentation", "snippets");
 my $new_snippet_dir = catdir($snippet_dir, "new");
 
-push @dirs, catdir($top_source, $snippet_dir);
-push @dirs, catdir($top_source, $new_snippet_dir) unless $no_new;
+unless ($no_lsr && $no_snippet_list && $no_new) {
+  my @dirs;
 
-for my $dir (@dirs) {
-  die "error: No directory '$dir'\n" unless -d $dir;
-  die "error: Directory '$dir' is not readable\n" unless -r $dir;
-  die "error: Directory '$dir' is not writable\n" unless -w $dir;
+  push @dirs, catdir($top_source, $snippet_dir);
+  push @dirs, catdir($top_source, $new_snippet_dir) unless $no_new;
+
+  for my $dir (@dirs) {
+    die "error: No directory '$dir'\n" unless -d $dir;
+    die "error: Directory '$dir' is not readable\n" unless -r $dir;
+    die "error: Directory '$dir' is not writable\n" unless -w $dir;
+  }
 }
 
 
 # Change to the top source directory for simplicity.
 my $curr_dir = rel2abs(curdir);
-chdir $top_source;
+chdir $top_source
+  or die "error: Can't change to directory '$top_source'\n";
 
 
 # Clean up.
-if (!$no_lsr) {
+unless ($no_lsr) {
   print "Removing old snippet files\n";
   while (my $f = glob(catfile($snippet_dir, "*.ly"))) {
     unlink $f or warn "warning: Can't remove file '$f': $!";
   }
 }
 
-if (!$no_snippet_list && !$no_lsr) {
+unless ($no_snippet_list || $no_lsr) {
   print "Removing old snippet list files\n";
   while (my $f = glob(catfile($snippet_dir, "*.snippet-list"))) {
     unlink $f or warn "warning: Can't remove file '$f': $!";
@@ -544,7 +561,7 @@ if ($textdump) {
 
 # Handle new snippets.  We expect them to have a structure similar to
 # snippets derived from the LSR database.
-if (!$no_new) {
+unless ($no_new) {
   print "Examining snippets in subdirectory 'new'\n";
   opendir my $dh, $new_snippet_dir
     or die "error: Can't open directory '$new_snippet_dir': $!\n";
@@ -794,7 +811,7 @@ for my $entry (@{$snippet_table}) {
 }
 
 
-if (!$no_snippet_list) {
+unless ($no_snippet_list) {
   # Write snippet lists.  No need to parallelize this since it is very
   # quick.
   print "Creating snippet list files\n";
@@ -830,6 +847,9 @@ if (!$no_snippet_list) {
 }
 
 
+exit 0 if ($no_lsr && $no_new);
+
+
 # Function:
 #   Convert HTML data into the Texinfo format.
 #
@@ -1052,8 +1072,8 @@ for my $entry (sort { $a->{"filename"} cmp $b->{"filename"} }
       # We have to remove '%LSR' comments, which are not intended to
       # be exported from the LSR.
       $snippet .= "\n";
-      $snippet =~ s/^ \h* %+ \h* LSR .* \n//gmx; # '%LSR' on a line of its own.
-      $snippet =~ s/\h* %+ \h* LSR .* $//gmx; # Trailing '%LSR'.
+      $snippet =~ s/^ \h* %+ \h* LSR .* \n//gmx; # `%LSR` on a line of its own.
+      $snippet =~ s/\h* %+ \h* LSR .* $//gmx; # Trailing `%LSR`.
 
       $data .= $snippet;
 
