@@ -1,6 +1,6 @@
 #!@TARGET_PYTHON@
 
-# Copyright (c) 2006--2021 Brailcom, o.p.s.
+# Copyright (c) 2006--2022 Brailcom, o.p.s.
 #
 # Author: Milan Zamazal <pdm@brailcom.org>
 #
@@ -130,8 +130,8 @@ def process_xml_file(file_name, voice, speedup, play_program):
         if recodep:
             decode = codecs.getdecoder('utf-8')
             encode = codecs.getencoder(coding)
-        input = open(file_name, encoding='utf8')
-        output = open(xml_temp_file, 'w', encoding='utf8')
+        input = open(file_name, encoding='utf-8')
+        output = open(xml_temp_file, 'w', encoding='utf-8')
         while True:
             data = input.read()
             if not data:
